<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>AppearanceManager</name>
    <message>
        <source>Display scaling</source>
        <translation>屏幕缩放</translation>
    </message>
    <message>
        <source>Log out for display scaling settings to take effect</source>
        <translation>屏幕缩放需注销后才能生效</translation>
    </message>
    <message>
        <source>Set successfully</source>
        <translation>设置成功</translation>
    </message>
    <message>
        <source>Log Out Now</source>
        <translation>立即注销</translation>
    </message>
    <message>
        <source>Later</source>
        <translation>稍后注销</translation>
    </message>
    <message>
        <source>Start setting display scaling, please wait patiently</source>
        <translation>开始设置屏幕缩放，请耐心等待</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>This system wallpaper is locked. Please contact your admin.</source>
        <translation>当前系统壁纸已被锁定，请联系管理员</translation>
    </message>
</context>
</TS>
